@@ -279,10 +279,10 @@ class Gui(gtk.VBox, cfg.ConfigUtils):
         req = self.m_t.m_P.get_test_requirement()
         res = self.m_t.m_statistics.get()
         if res >= req:
-            gu.dialog_ok(_("Test completed!\nYour score was %.1f%%.\nThe test requirement was %.1f%%.") % (res * 100, req * 100))
+            gu.dialog_ok(_("Test completed!\nYour score was %(score).1f%%.\nThe test requirement was %(requirement).1f%%.") % {'score': res * 100, 'requirement': req * 100})
             self.m_t.m_statistics.store_test_passed()
         else:
-            gu.dialog_ok(_("Test failed.\nYour score was %.1f%%.\nThe test requirement was %.1f%%.") % (res * 100, req * 100))
+            gu.dialog_ok(_("Test failed.\nYour score was %(score).1f%%.\nThe test requirement was %(requirement).1f%%.") % {'score': res * 100, 'requirement': req * 100})
         self.g_cancel_test.hide()
         self.g_win.exit_test_mode()
     def set_lesson_heading(self, txt):
