@@ -25,6 +25,7 @@ import abstract
 import os
 import cfg, utils
 import webbrowser
+import gu
 from osutils import *
 
 def linux_play_wav_file(filename):
@@ -254,7 +255,7 @@ It is also possible that the OS sound setup is incorrect.
                     cmdline = "%s %s" % (self.get_string("config/mua"), urlobj.href)
                 os.system(cmdline)
             else:
-                self.m_ui.dialog_ok(_("You have not selected email program. You can do so in the preferences window."))
+                gu.dialog_ok(_("You have not selected email program. You can do so in the preferences window."))
         else:
             print "unknown link type", urlobj.protocol
     def handle_solfege_href(self, urlobj):
@@ -281,7 +282,7 @@ It is also possible that the OS sound setup is incorrect.
             try:
                 self.m_teachers[p.header.module].m_P.header[key] = eval(val)
             except SyntaxError:
-                self.m_ui.dialog_ok(_("Bad url parameter in link: '%s=%s'.\nTrying to continue anyway.") % (key, val))
+                gu.dialog_ok(_("Bad url parameter in link: '%s'.\nTrying to continue anyway.") % ("%s=%s" % (key, val)))
         self.m_ui.box_dict[p.header.module].on_start_practise()
     def create_teacher(self, modulename):
         """
