@@ -499,9 +499,9 @@ class Gui(abstract.LessonbasedGui):
             if toptone_txt:
                 v.append(toptone_txt)
             if len(v) == 3:
-                self.g_flashbar.flash(_("%s, %s and %s") % tuple(v))
+                self.g_flashbar.flash(_("%(one)s, %(two)s and %(three)s") % {'one': v[0], 'two': v[1], 'three': v[2]})
             elif len(v) == 2:
-                self.g_flashbar.flash(_("%s and %s") % tuple(v))
+                self.g_flashbar.flash(_("%(one)s and %(two)s") % {'one': v[0], 'two': v[1]})
             else:
                 self.g_flashbar.flash(type_txt)
             self.g_new.set_sensitive(True)
