@@ -698,6 +698,8 @@ class Window(gtk.Window):
         self.__load_file2_lock = 0
     def fill_trees_combo(self):
         self.m_trees = [('solfege', 'learningtree.txt', os.path.join(os.getcwd(), 'learningtree.txt'))]
+        if self.m_app.m_options.debug:
+            self.m_trees.append(('solfege', 'debugtree.txt', os.path.join(os.getcwd(), 'debugtree.txt')))
         try:
             v = os.listdir(os.path.join(gethomedir.get_home_dir(), ".solfege", "learningtrees"))
         except OSError:
@@ -706,7 +708,7 @@ class Window(gtk.Window):
             self.m_trees.append(('user', fn, os.path.join(gethomedir.get_home_dir(), ".solfege", "learningtrees", fn)))
         self.g_trees_liststore.clear()
         for t, fn, txt in self.m_trees:
-            self.g_trees_liststore.append((txt,))#_text(txt)
+            self.g_trees_liststore.append((txt,))
     def set_trees_combo(self, place, filename):
         # Set the combo to the correct learning tree.
         self.__load_file2_lock += 1
