@@ -707,14 +707,15 @@ class QuestionsLessonfile(LessonfileCommon):
         """Return a list created from the instrument variable the question.
         Use app default values if the variable is missing.
         Convert instrument names to integer values.
+        Returns: lowest, middle, highest
         """
         if self.m_t.get_bool('config/override_default_instrument'):
-            instrument = [self.m_t.get_int('config/highest_instrument'),
-                         self.m_t.get_int('config/highest_instrument_velocity'),
+            instrument = [self.m_t.get_int('config/lowest_instrument'),
+                         self.m_t.get_int('config/lowest_instrument_velocity'),
                          self.m_t.get_int('config/middle_instrument'),
                          self.m_t.get_int('config/middle_instrument_velocity'),
-                         self.m_t.get_int('config/lowest_instrument'),
-                         self.m_t.get_int('config/lowest_instrument_velocity')]
+                         self.m_t.get_int('config/highest_instrument'),
+                         self.m_t.get_int('config/highest_instrument_velocity')]
         elif 'instrument' in question:
             instrument = question['instrument']
         elif 'instrument' in self.m_globals:
