@@ -1,3 +1,4 @@
+# -*- coding: iso-8859-1 -*-
 # GNU Solfege - ear training for GNOME
 # Copyright (C) 2004, 2005, 2006  Tom Cato Amundsen
 #
@@ -247,8 +248,9 @@ class MainWin(gtk.Window):
             self.set_title(self.m_P.m_filename)
         else:
             self.set_title(_("No file"))
-        self.g_navinfo.set_text(_("question %i of %i") % (self.m_P._idx + 1,
-                len(self.m_P.m_questions)))
+        self.g_navinfo.set_text(_("question %(idx)i of %(count)i") % {
+            'idx': self.m_P._idx + 1,
+            'count': len(self.m_P.m_questions)})
         self.g_question_name.set_text(self.m_P.m_questions[self.m_P._idx]['name'])
     def load_file(self, filename):
         self.m_P = lessonfile.ChordLessonfile(filename, None)
@@ -285,7 +287,8 @@ class MainWin(gtk.Window):
                 dialog.destroy()
                 m = gtk.MessageDialog(self, gtk.DIALOG_MODAL, gtk.MESSAGE_ERROR,
                         gtk.BUTTONS_CLOSE,
-                        _("Loading file '%s' failed: %s") % (filename, e))
+                        _("Loading file '%(filename)s' failed: %(msg)s") %
+                            {'filename': filename, 'msg': e})
                 m.run()
                 m.destroy()
             else:
