@@ -16,7 +16,7 @@
 # Foundation, Inc., 51 Franklin ST, Fifth Floor, Boston, MA  02110-1301  USA
 
 from __future__ import division
-import gtk, gnome.ui, gobject
+import gtk, gobject
 import abstract, const, gu, mpd, soundcard
 import random, os
 import cfg
@@ -42,13 +42,13 @@ RHYTHMS = ("c4", "c8 c8", "c16 c16 c16 c16", "c8 c16 c16",
            )
 
 
-class Teacher(abstract.LessonbasedTeacher):
+class Teacher(abstract.Teacher):
     OK = 0
     ERR_PICKY = 1
     ERR_NO_ELEMS = 2
     def __init__(self, exname, app):
-        abstract.LessonbasedTeacher.__init__(self, exname, app)
-        self.lessonfileclass = lessonfile.IdByNameLessonfile
+        abstract.Teacher.__init__(self, exname, app)
+        self.lessonfileclass = lessonfile.HeaderLessonfile
     def new_question(self):
         """returns:
                Teacher.ERR_PICKY : if the question is not yet solved and the
@@ -97,7 +97,12 @@ class Teacher(abstract.LessonbasedTeacher):
     def play_question(self):
         if self.q_status == const.QSTATUS_NO:
             return
-        score = mpd.parser.parse_to_score_object(self.get_music_string())
+        self.play_rhythm(self.get_music_string())
+    def play_rhythm(self, rhythm):
+        """
+        rhythm is a string. Example: 'c4 c8 c8 c4'
+        """
+        score = mpd.parser.parse_to_score_object(rhythm)
         track = score.get_midi_events_with_channel(9, cfg.get_int('config/preferred_instrument_velocity'))[0]
         track.prepend_bpm(self.get_int("bpm"))
         track.replace_note(mpd.notename_to_int("c"),
@@ -145,8 +150,8 @@ class RhythmViewer(gtk.Frame):
         self.g_parent = parent
         self.g_box = gtk.HBox()
         self.g_box.show()
-        self.g_box.set_spacing(gnome.ui.PAD_SMALL)
-        self.g_box.set_border_width(gnome.ui.PAD)
+        self.g_box.set_spacing(gu.PAD_SMALL)
+        self.g_box.set_border_width(gu.PAD)
         self.add(self.g_box)
         self.m_data = []
         # the number of rhythm elements the viewer is supposed to show
@@ -255,65 +260,33 @@ class RhythmViewer(gtk.Frame):
         self.g_box.pack_start(l, True, True)
         lx, ly = l.size_request()
         sx, sy = self.g_box.size_request()
-        self.g_box.set_size_request(max(lx + gnome.ui.PAD * 2, sx), max(ly + gnome.ui.PAD * 2, sy))
+        self.g_box.set_size_request(max(lx + gu.PAD * 2, sx), max(ly + gu.PAD * 2, sy))
         self.__timeout = gobject.timeout_add(const.NORMAL_WAIT, self.unflash)
     def unflash(self, *v):
         self.__timeout = None
         self.clear()
 
-class NewLineBox(gtk.VBox):
-    def __init__(self):
-        gtk.VBox.__init__(self)
-    def add_widget(self, widget):
-        self.m_todo_widgets.append(widget)
-    def show_widgets(self):
-        if 'newline' in self.m_todo_widgets:
-            self._newline_show_widgets()
-        else:
-            self._flow_show_widgets()
-    def newline(self):
-        self.m_todo_widgets.append('newline')
-    def _newline_show_widgets(self):
-        sizegroup = gtk.SizeGroup(gtk.SIZE_GROUP_HORIZONTAL)
-        hbox = gu.bHBox(self, True)
-        for n in self.m_todo_widgets:
-            if n == 'newline':
-                hbox = gu.bHBox(self, False)
-            else:
-                hbox.pack_start(n, False)
-                sizegroup.add_widget(n)
-    def _flow_show_widgets(self):
-        w = 8
-        num_lines = len(self.m_todo_widgets) // w + 1
-        w = len(self.m_todo_widgets) // num_lines + 1
-        sizegroup = gtk.SizeGroup(gtk.SIZE_GROUP_HORIZONTAL)
-        c = 0
-        for n in self.m_todo_widgets:
-            sizegroup.add_widget(n)
-            if c % w == 0:
-                hbox = gu.bHBox(self, False)
-            hbox.pack_start(n, False)
-            c += 1
-        self.show_all()
-    def empty(self):
-        self.foreach(lambda w: w.destroy())
-        self.m_todo_widgets = []
-
 class Gui(abstract.Gui):
     num_buttons_in_row = 8
     def __init__(self, teacher, window):
         abstract.Gui.__init__(self, teacher, window)
         self.m_key_bindings = {'backspace_ak': self.on_backspace}
-        self.g_answer_box = NewLineBox()
+        self.g_answer_box = gu.NewLineBox()
         self.practise_box.pack_start(self.g_answer_box, False)
         #-------
+        hbox = gu.bHBox(self.practise_box)
+        b = gtk.Button(_("Play"))
+        b.show()
+        b.connect('clicked', self.play_users_answer)
+        hbox.pack_start(b, False, True)
         self.practise_box.pack_start(gtk.HBox(), False,
-                                     padding=gnome.ui.PAD_SMALL)
+                                     padding=gu.PAD_SMALL)
         self.g_rhythm_viewer = RhythmViewer(self)
         #FIXME the value 52 is dependant on the theme used
         self.g_rhythm_viewer.set_size_request(-1, 52)
         self.g_rhythm_viewer.create_holders()
-        self.practise_box.pack_start(self.g_rhythm_viewer, False)
+        hbox.pack_start(self.g_rhythm_viewer)
+        #self.practise_box.pack_start(self.g_rhythm_viewer, False)
 
         # action area
         self.g_new = gu.bButton(self.action_area, _("_New"), self.new_question)
@@ -331,19 +304,19 @@ class Gui(abstract.Gui):
         ##############
         self.g_element_frame = frame = gtk.Frame(_("Rhythms to use in question"))
         self.config_box.pack_start(frame, False)
-        self.g_select_rhythms_box = NewLineBox()
-        self.g_select_rhythms_box.set_border_width(gnome.ui.PAD_SMALL)
+        self.g_select_rhythms_box = gu.NewLineBox()
+        self.g_select_rhythms_box.set_border_width(gu.PAD_SMALL)
         frame.add(self.g_select_rhythms_box)
         #--------    
         self.config_box.pack_start(gtk.HBox(), False,
-                                   padding=gnome.ui.PAD_SMALL)
+                                   padding=gu.PAD_SMALL)
 
         table = gtk.Table(2, 4, False)
         self.config_box.pack_start(table, False)
         ###
         label = gtk.Label(_("Number of beats in question:"))
         label.set_alignment(1.0, 0.5)
-        table.attach(label, 0, 1, 0, 1, xpadding=gnome.ui.PAD_SMALL,
+        table.attach(label, 0, 1, 0, 1, xpadding=gu.PAD_SMALL,
                       xoptions=gtk.FILL)
         table.attach(gu.nSpinButton(self.m_exname, "num_beats",
                      gtk.Adjustment(4, 1, 100, 1, 10)),
@@ -352,7 +325,7 @@ class Gui(abstract.Gui):
         table.attach(menu, 2, 3, 0, 1, xoptions=gtk.FILL)
         label = gtk.Label(_("Count in before question:"))
         label.set_alignment(1.0, 0.5)
-        table.attach(label, 0, 1, 1, 2, xpadding=gnome.ui.PAD_SMALL,
+        table.attach(label, 0, 1, 1, 2, xpadding=gu.PAD_SMALL,
                      xoptions=gtk.FILL)
         table.attach(gu.nSpinButton(self.m_exname, "count_in",
                      gtk.Adjustment(2, 0, 10, 1, 10)),
@@ -361,10 +334,10 @@ class Gui(abstract.Gui):
         table.attach(menu, 2, 3, 1, 2, xoptions=gtk.FILL)
         #-----
         self.config_box.pack_start(gtk.HBox(), False,
-                                   padding=gnome.ui.PAD_SMALL)
+                                   padding=gu.PAD_SMALL)
         #------
         hbox = gu.bHBox(self.config_box, False)
-        hbox.set_spacing(gnome.ui.PAD_SMALL)
+        hbox.set_spacing(gu.PAD_SMALL)
         hbox.pack_start(gu.nCheckButton(self.m_exname,
                  "not_start_with_rest",
                  _("Don't start the question with a rest")), False)
@@ -424,6 +397,9 @@ class Gui(abstract.Gui):
         self.g_rhythm_viewer.backspace()
         if not self.g_rhythm_viewer.m_data:
             self.g_backspace.set_sensitive(False)
+    def play_users_answer(self, widget):
+        rhythm = " ".join([RHYTHMS[c] for c in self.g_rhythm_viewer.m_data])
+        self.m_t.play_rhythm(r"\staff{ %s }" % rhythm)
     def guess_element(self, sender, i):
         if self.m_t.q_status == const.QSTATUS_NO:
             self.g_rhythm_viewer.flash(_("Click 'New' to begin."))
