@@ -27,8 +27,6 @@ import sys
 import os
 
 _has_gtkhtml2 = None
-_has_gnome_canvas = None
-_has_gnome = None
 use_cairo_widgets = None
 
 def assert_python_version(required_version):
@@ -59,18 +57,12 @@ def setup_pygtk(required_version):
 
 def init(options):
     global _has_gtkhtml2
-    global _has_gnome
-    global _has_gnome_canvas
     global use_cairo_widgets
     assert_python_version((2, 3))
     setup_pygtk((2, 4))
     if options.without_gtkhtml:
         _has_gtkhtml2 = False
         print "gtkhtml2: disabled by runtime option"
-    if options.without_gnome:
-        _has_gnome = False
-        _has_gnome_canvas = False
-        print "gnome: disabled by runtime option"
     if options.no_cairo_widgets:
         use_cairo_widgets = False
     else:
@@ -96,42 +88,3 @@ def has_gtkhtml2():
         _has_gtkhtml2 = False
     return _has_gtkhtml2
 
-def has_gnome_canvas():
-    global _has_gnome_canvas
-    if _has_gnome_canvas is not None:
-        return _has_gnome_canvas
-    print "Checking for gnomecanvas...",
-    try:
-        import gnomecanvas
-        _has_gnome_canvas = True
-        print "ok"
-        return True
-    except ImportError, e:
-        print e
-        pass
-    print "Checking for gnome.canvas..."
-    try:
-        import gnome.canvas
-        try:
-            gnome.canvas.not_real_canvas
-        except:
-            print "ok"
-            _has_gnome_canvas = True
-    except ImportError, e:
-        print e
-        _has_gnome_canvas = False
-    return _has_gnome_canvas
-
-def has_gnome():
-    global _has_gnome
-    if _has_gnome is not None:
-        return _has_gnome
-    print "Checking for gnome",
-    try:
-        import gnome
-        print "ok"
-        _has_gnome = True
-    except ImportError, e:
-        print e
-        _has_gnome = False
-    return _has_gnome
