@@ -15,7 +15,7 @@
 # along with this program; if not, write to the Free Software
 # Foundation, Inc., 51 Franklin ST, Fifth Floor, Boston, MA  02110-1301  USA
 
-import gtk, gnome
+import gtk
 import gu
 from multipleintervalconfigwidget import MultipleIntervalConfigWidget
 import soundcard, mpd, mpd.musicdisplayer
@@ -28,15 +28,12 @@ import random
 class Teacher(abstract.MelodicIntervalTeacher):
     def __init__(self, exname, app):
         abstract.MelodicIntervalTeacher.__init__(self, exname, app)
-        self.lessonfileclass = lessonfile.IdByNameLessonfile
+        self.lessonfileclass = lessonfile.IntervalsLessonfile
         self._ignore_picky = 1
         self.m_statistics = statistics.IntervalStatistics(self)
     def enter_test_mode(self):
         self.m_statistics.enter_test_mode()
-        count, t = lessonfile.parse_test_def(self.m_P.header.test)
-        self.m_test_questions = self.get_list('ask_for_intervals_0') * count
-        random.shuffle(self.m_test_questions)
-        self.m_test_idx = -1
+        self.m_P.enter_test_mode()
     def get_question(self):
         s = self.m_tonika.get_octave_notename()
         last = self.m_tonika
@@ -118,7 +115,7 @@ class Gui(abstract.Gui):
         # statistics
         ###############
         self.setup_statisticsviewer(
-           statisticsviewer.SingIntervalStatisticsViewer, _("Sing interval"))
+           statisticsviewer.PercentagesStatisticsViewer, _("Sing interval"))
     def _new_question(self):
         r = self.m_t.new_question(self.get_string('user/lowest_pitch'),
                                   self.get_string('user/highest_pitch'))
@@ -165,6 +162,7 @@ class Gui(abstract.Gui):
         else:
             self.g_mici.hide()
             self.m_t.m_statistics.reset_session()
+        self.g_statview.g_heading.set_text("%s - %s" % (_("Sing interval"), self.m_t.m_P.header.title))
         self.handle_config_box_visibility()
         self.g_new_interval.grab_focus()
     def on_end_practise(self):
@@ -179,7 +177,7 @@ class Gui(abstract.Gui):
     def new_last_was_wrong(self, widget=None):
         if self.m_t.q_status == const.QSTATUS_NEW:
             self.m_t.guessed_wrong()
-            if self.m_t.m_app.m_test_mode and self.m_t.is_test_complete():
+            if self.m_t.m_app.m_test_mode and self.m_t.m_P.is_test_complete():
                 self.do_test_complete()
                 return
         self._new_question()
@@ -187,7 +185,7 @@ class Gui(abstract.Gui):
                  # teacher when we get a new question automatically.
         if self.m_t.q_status == const.QSTATUS_NEW:
             self.m_t.guessed_correct()
-            if self.m_t.m_app.m_test_mode and self.m_t.is_test_complete():
+            if self.m_t.m_app.m_test_mode and self.m_t.m_P.is_test_complete():
                 self.do_test_complete()
                 return
         r = self._new_question()
