@@ -84,7 +84,9 @@ class TracebackWindow(gtk.Dialog):
         d.destroy()
     def write(self, txt):
         if ("DeprecationWarning:" in txt) or \
-           (not self.m_show_gtk_warnings and "GtkWarning" in txt):
+           (not self.m_show_gtk_warnings and (
+            "GtkWarning" in txt or
+            "PangoWarning" in txt)):
             print txt
             return
         sys.stdout.write(txt)
